@@ -158,7 +158,7 @@ def main():
     # Subparser for creating a queue
     parser_create_queue = subparsers.add_parser("create_queue", help="Create a queue")
     parser_create_queue.add_argument("qm_name", help="Name of the queue manager")
-    parser_create_queue.add.argument("queue_name", help="Name of the queue to create")
+    parser_create_queue.add_argument("queue_name", help="Name of the queue to create")
     parser_create_queue.set_defaults(func=create_queue)
     parser_create_queue.epilog = """
     Example usage:
@@ -168,9 +168,9 @@ def main():
 
     # Subparser for configuring a queue
     parser_configure_queue = subparsers.add_parser("configure_queue", help="Configure a queue")
-    parser_configure_queue.add.argument("qm_name", help="Name of the queue manager")
-    parser_configure_queue.add.argument("queue_name", help="Name of the queue to configure")
-    parser_configure_queue.add.argument("configuration", help="Configuration string for the queue")
+    parser_configure_queue.add_argument("qm_name", help="Name of the queue manager")
+    parser_configure_queue.add_argument("queue_name", help="Name of the queue to configure")
+    parser_configure_queue.add_argument("configuration", help="Configuration string for the queue")
     parser_configure_queue.set_defaults(func=configure_queue)
     parser_configure_queue.epilog = """
     Example usage:
@@ -180,7 +180,7 @@ def main():
 
     # Subparser for starting a queue manager
     parser_start_qm = subparsers.add_parser("start_qm", help="Start a queue manager")
-    parser_start_qm.add.argument("name", help="Name of the queue manager to start")
+    parser_start_qm.add_argument("name", help="Name of the queue manager to start")
     parser_start_qm.set_defaults(func=start_queue_manager)
     parser_start_qm.epilog = """
     Example usage:
@@ -190,7 +190,7 @@ def main():
 
     # Subparser for stopping a queue manager
     parser_stop_qm = subparsers.add_parser("stop_qm", help="Stop a queue manager")
-    parser_stop_qm.add.argument("name", help="Name of the queue manager to stop")
+    parser_stop_qm.add_argument("name", help="Name of the queue manager to stop")
     parser_stop_qm.set_defaults(func=stop_queue_manager)
     parser_stop_qm.epilog = """
     Example usage:
@@ -200,7 +200,7 @@ def main():
 
     # Subparser for displaying queues
     parser_display_queues = subparsers.add_parser("display_queues", help="Display all queues in a queue manager")
-    parser_display_queues.add.argument("qm_name", help="Name of the queue manager")
+    parser_display_queues.add_argument("qm_name", help="Name of the queue manager")
     parser_display_queues.set_defaults(func=display_queues)
     parser_display_queues.epilog = """
     Example usage:
@@ -210,8 +210,8 @@ def main():
 
     # Subparser for getting queue permissions
     parser_get_permissions = subparsers.add_parser("get_permissions", help="Get permissions for a user on all queues in a queue manager")
-    parser_get_permissions.add.argument("qm_name", help="Name of the queue manager")
-    parser_get_permissions.add.argument("user", help="Name of the user")
+    parser_get_permissions.add_argument("qm_name", help="Name of the queue manager")
+    parser_get_permissions.add_argument("user", help="Name of the user")
     parser_get_permissions.set_defaults(func=get_queue_permissions)
     parser_get_permissions.epilog = """
     Example usage:
@@ -221,9 +221,9 @@ def main():
 
     # Subparser for putting a message on a queue
     parser_put_message = subparsers.add_parser("put_message", help="Put a message on a queue")
-    parser_put_message.add.argument("qm_name", help="Name of the queue manager")
-    parser_put_message.add.argument("queue_name", help="Name of the queue")
-    parser_put_message.add.argument("message", help="Message to put on the queue")
+    parser_put_message.add_argument("queue_name", help="Name of the queue")
+    parser_put_message.add_argument("qm_name", help="Name of the queue manager")
+    parser_put_message.add_argument("message", help="Message to put on the queue")
     parser_put_message.set_defaults(func=put_message)
     parser_put_message.epilog = """
     Example usage:
@@ -233,8 +233,8 @@ def main():
 
     # Subparser for getting a message from a queue
     parser_get_message = subparsers.add_parser("get_message", help="Get a message from a queue")
-    parser_get_message.add.argument("qm_name", help="Name of the queue manager")
-    parser_get_message.add.argument("queue_name", help="Name of the queue")
+    parser_get_message.add_argument("qm_name", help="Name of the queue manager")
+    parser_get_message.add_argument("queue_name", help="Name of the queue")
     parser_get_message.set_defaults(func=get_message)
     parser_get_message.epilog = """
     Example usage:
